% Faltinsen's formula for head waves, equation (6.1) 
% calculated for the 1st speed trial run of S155
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUTS
% General data
rho=1025; % Density of sea water
g=9.81; % Acceleration due to gravity
hsig=1.52; % Significant wave height
vs=15.61*0.5144; % Ship speed over ground converted from knots to m/s
l=272; % Length of the vessel in the waterline
fn=vs/sqrt(g*l); % Froude number
t=4.5 % Mean wave period, T_1

%% Coordinates along the bow obtained from the line drawings
xy=[0 24;
    2 24;
    4 23.9;
    6 23.85;
    8 23.75;
    10 23.7;
    12 23.5;
    14 23.35;
    16 23.1;
    18 22.9;
    20 22.6;
    22 22.3;
    24 21.9;
    26 21.5;
    28 20.95;
    30 20.45;
    32 19.85;
    33 19.55;
    34 19.1;
    35 18.8;
    36 18.45; 
    37 18.05;
    38 17.65;
    40 16.65;
    42 15.6;
    44 14.6;
    46 13.35;
    48 11.95;
    50 10.45;
    52 8.75;
    54 6.85;
    55 5.8;
    56 4.7;
    57 3.4;
    58 2;
    59 0];

dxq=0.1; % Step in the x-direction

xq=[0:dxq:59]; % Creates a matrix from x=0 to x=59 with a step of 0.1

yq=interp1(xy(:,1),xy(:,2),xq); % Interpolation for creating additional 
                                % intermediate coordinates

figure_i=length(findobj('Type','figure'));

% Plots the bow area
figure(figure_i+1);
hold on;
plot(xy(:,1),xy(:,2));
plot(xq,yq,'o');
title('Function y=y(x)');
hold off;

diff_yq=diff(yq)/dxq; % Derives y with respect to x

l_diff_yq=length(diff_yq); 

theta=atan(-diff_yq); % Calculates the angle theta 

figure_i=length(findobj('Type','figure')); % Gives a figure of the results
figure(figure_i+1);
hold on;
plot(xq(1:l_diff_yq),theta);
title('\theta=\theta(x)');
hold off;

ds=sqrt(1+diff_yq.^2); % Expresses the bow arc

n1=sin(theta); % Gives the n1=sin(theta) (decomposed n)

dF=sin(theta).^2.*n1.*ds; %Gives an expression of a small force component

F=trapz(xq(1:l_diff_yq),dF); % Numerical approach to solve the integral
                             % The trapezoidal rule is used 
                      
% The constant part of equation (6.1). Note that is is multiplied by 
%2 as only half the bow has been included so far

faltk=2*rho*g*hsig^2/16*(1+fn*4*pi/t*sqrt(l/g)); 

% Solution of equation (6.1). Note that is is multiplied by 2 as only
% half the bow has been included so far

falt=2*rho*g*hsig^2/16*(1+fn*4*pi/t*sqrt(l/g))*F 
