% Faltinsen's formula for oblique waves
% Reading Skejics's output file. 
% Regular waves --> irregular waves by equation (6.14).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUTS
% General data (constant)
n   = 150;      % j, number of output-values
rho = 1025;     % Density
g   = 9.81;     % Gravity
B   = 48;       % Vessel beam
Lwl = 272;      % Vessel length in waterline

% Spectral data (variables)
Hs  =1.5;        % Significant wave-height
T01 = 7.5;      % Mean wave period     

%% Filename of outputfile from Skejic's program. 
% Contains a dimensionless added resistance for 150 different lambda/LWL
filename = 'Raw120_58_NO1374_15_52knopny(3).txt';
fileid   = fopen(filename);

%Reading title (2 lines)
for i = 1:2;
    fgetl(fileid);
end

% Creating vectors to store:
% lamLwl = Dimensionless lambda (lambda/LWL)
% Fd = Dimensionless added resistance in regular waves
% F_zeta = Response function
% Sw = Energy spectrum (standard ITTC spectrum)
[lamLwl,Fd,Sw,F_zeta] = deal(zeros(n,1));

for i = 1:n;
    % Reading values for each step
    read = fscanf(fileid,'%f',5);
    
    lamLwl(i) = read(3);
    Fd(i)    = read(5);   
end

plot(lamLwl,Fd)

lambda = lamLwl*Lwl; % Lambda    
freqs  = sqrt(2.*pi.*g./lambda); % Omega corresponding to lambda


F_tot = 0;

for i = 1:n;
    
    % Frequency
    w  = freqs(i);   
    
    if i<n
        dw = abs(freqs(i)-freqs(i+1));
    end
    
    % Specter 
    Sw(i)     = 172.8*Hs^2/T01^4*w^-5*exp(-691/T01^4*w^-4);
   
    % Response function
    F_zeta(i) = Fd(i)*rho*g*B^2/Lwl;
    
    % Total added resisitance
    F_tot = F_tot + 2*Sw(i)*F_zeta(i)*dw; % Equation (6.14) for irr. waves
   
end

-F_tot













