clear all
% Fujii and Takashi's method (equation (4.5))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUTS
rho = 1025;                   % Density of sea water
g   = 9.81;                   % Gravity
d   = 16;                     % draught
Lwl = 272;                    % Length waterline
U   = 15.61*0.5144;           % Ship speed converted from knots --> m/s


% Spectral data 
Hs  =1.52;                     % Significant wave-height
T1 = 4.5;                     % Mean wave period     
%% 

Fn = U/sqrt(g*Lwl);              % Froude number

lamLwlMax = 0.5;                 % Max value of lambda/Lwl                     
lamMax = lamLwlMax*Lwl;          % Max value of lambda
wMin   = sqrt(2*pi*g/lamMax);    % Corresponding minimum value of omega
dw    = 0.1;                     % Step of omega
freqs = wMin:dw:4;               % Values from wMin to omega max = 4
                                 % with a step of 0.1
n     = length(freqs);

Fd = zeros(n,1);            % Preallocating
Bow    = bow;               % Calling function bow.m
Fujiimod  = 0;

for i = 1:n;
    
    w = freqs(i);
    
    k  = w^2/g;                 % Wave number 
    
    % Besstel functions as a function of k
    kf = k*d*1.5;               % Input parameter for Bessel function
    Bessel1 = besseli(1,kf);    % Bessel 1st kind
    Bessel2 = besselk(1,kf);    % Bessel 2nd kind
    
    alpha1 = pi^2*Bessel1^2/(pi^2*Bessel1^2 + Bessel2^2); %alpha1  
    alpha2 = 3.5*Fn^0.5;                                    
    
    % Response function (Force divided by zeta^2)
    Fd(i) = alpha1*(1+alpha2)*0.5*rho*g*bow;            
    
       
    % ITCC specter 
    Sw  = 172.8*Hs^2/T1^4*w^-5*exp(-691/T1^4*w^-4);
    
    % Total added resisitance equation (4.5)
    Fujiimod = Fujiimod + 2*Sw*Fd(i)*dw;
    
    
end

Fujiimod




