clear all
% Fujii and Takashi's method (equation (6.24))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% INPUTS
rho = 1025;                   % density
g   = 9.81;                   % Gravity
d   = 16;                     % draught
Lwl = 272;                    % Length waterline
U   = 15.61*0.5144;           % Ship speed converted from knots --> m/s


% Spectral data 
Hs  =1.52;                     % Significant wave-height
T1 = 8;                     % Mean wave period     
%% 

Fn = U/sqrt(g*Lwl);           % Froude number

lamLwlMax = 0.5;              % Upper limit for lambda/Lwl
lamMax = lamLwlMax*Lwl;       % Upper limit for lambda
wMin   = sqrt(2*pi*g/lamMax); % Corresponding lower limit for omega
dw    = 0.1;                  % Step of omega
freqs = wMin:dw:6;            % Omega values from wMin to omega max=6
                              % with a step of 0.1
n     = length(freqs);

RawHyundai = zeros(n,1);    % Preallocating
RawFujiTak = zeros(n,1);    % Preallocating
Bow    = bow;               % Calling function bow.m which is the solution 
                            % of the integral within equation (6.24)
F_Hyu  = 0;                 
F_Fuj  = 0;

for i = 1:n;                
    
    w = freqs(i);
    
    k  = w^2/g;                 % Wave number 
    
    
    
    % Calculates the Bessel funcitons as a function of k
    kf = k*d;                   % Reduced frequency
    Bessel1 = besseli(1,kf);    % Bessel function of the 1st kind
    Bessel2 = besselk(1,kf);    % Bessel function of the 2nd kind
    
    
    % Calculates alpha3 and alpha4
    alpha3=pi^2*Bessel1^2/(pi^2*Bessel1^2 + Bessel2^2);  
    alpha4=5*(U/sqrt(g*Lwl))^0.5  ;
    
    % Variable Fujii - response function
    
    Fd(i) = alpha3*(alpha4+1)*0.5*rho*g*bow;   
    
    % Specter and added resistance
    Sw(i)  = 172.75*Hs^2/T1^4*w^-5*exp(-691/T1^4*w^-4);
    
    
    % Total added resisitance Fujii and Takahashi method
    F_Fuj = F_Fuj + 2*Sw(i)*Fd(i)*dw;
    
end


F_Fuj 


